<?php

namespace Bixo\Offplan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Offplan\Models\Offplan;

class OffplanPolicy
{

    /**
     * Determine if the given user can view the offplan.
     *
     * @param UserPolicy $user
     * @param Offplan $offplan
     *
     * @return bool
     */
    public function view(UserPolicy $user, Offplan $offplan)
    {
        if ($user->canDo('offplan.offplan.view') && $user->isAdmin()) {
            return true;
        }

        return $offplan->user_id == user_id() && $offplan->user_type == user_type();
    }

    /**
     * Determine if the given user can create a offplan.
     *
     * @param UserPolicy $user
     * @param Offplan $offplan
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('offplan.offplan.create');
    }

    /**
     * Determine if the given user can update the given offplan.
     *
     * @param UserPolicy $user
     * @param Offplan $offplan
     *
     * @return bool
     */
    public function update(UserPolicy $user, Offplan $offplan)
    {
        if ($user->canDo('offplan.offplan.edit') && $user->isAdmin()) {
            return true;
        }

        return $offplan->user_id == user_id() && $offplan->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given offplan.
     *
     * @param UserPolicy $user
     * @param Offplan $offplan
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Offplan $offplan)
    {
        return $offplan->user_id == user_id() && $offplan->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given offplan.
     *
     * @param UserPolicy $user
     * @param Offplan $offplan
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Offplan $offplan)
    {
        if ($user->canDo('offplan.offplan.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given offplan.
     *
     * @param UserPolicy $user
     * @param Offplan $offplan
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Offplan $offplan)
    {
        if ($user->canDo('offplan.offplan.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
